@@ -1,4 +1,4 @@
-/* Copyright 2017 The Tor Project
+/* Copyright 2017--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.impl;
@@ -13,8 +13,7 @@ public class TestDescriptor extends DescriptorImpl {
     super(rawDescriptorBytes, offsetAndLength, null, blankLinesAllowed);
   }
 
-  protected TestDescriptor(byte[] rawDescriptorBytes, int[] offsetAndLength)
-      throws DescriptorParseException {
+  protected TestDescriptor(byte[] rawDescriptorBytes, int[] offsetAndLength) {
     super(rawDescriptorBytes, offsetAndLength, null);
   }
 }
